/*
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */
package org.apache.tools.ant.listener;

import org.apache.tools.ant.BuildEvent;
import org.apache.tools.ant.NoBannerLogger;

/**
 * Displays subproject names like {@link BigProjectLogger}
 * but is otherwise as quiet as {@link NoBannerLogger}.
 * @since Ant1.8.1
 */
public class SimpleBigProjectLogger extends NoBannerLogger {

    /**
     * Override point, extract the target name
     *
     * @param event the event to work on
     * @return the target name -including the owning project name (if non-null)
     */
    protected String extractTargetName(BuildEvent event) {
        String targetName = super.extractTargetName(event);
        String projectName = extractProjectName(event);
        if (projectName != null && targetName != null) {
            return projectName + '.' + targetName;
        } else {
            return targetName;
        }
    }

}
